@@ -14,6 +14,7 @@
 
 import unittest
 from tests import *
+from unify.helpers.pipeline.schema import FlowSchema
 
 
 class TestSourcesWithOrgID(unittest.TestCase):
@@ -128,8 +129,8 @@ class TestSourcesWithOrgID(unittest.TestCase):
     def test_append_data_v2(self):
         export = self.sources.append_dataset(
             data_set_id=test_dataset["id"],
-            content=open("tests/data_test.csv").read()
-            ,org_id=test_org
+            content=open("tests/data_test.csv").read(),
+            org_id=test_org
         )
 
         self.assertTrue("id" in export, export)
@@ -235,3 +236,97 @@ class TestSourcesWithOrgID(unittest.TestCase):
             self.assertTrue(True, "Dataset became ready")
         except Exception as e:
             self.assertTrue(False, e)
+
+    def test_create_empty_dataset(self):
+        """
+        Verify empty dataset can be created
+        :return:
+        """
+
+        try:
+            response = self.sources.create_command(
+                org_id=test_org,
+                schema={
+                    "columns": [
+                        {
+                            "header": "name",
+                            "column": {
+                                "type": "text",
+                                "properties": {
+                                    "optional": False,
+                                    "datasets.v1.columnType": "Normal"
+                                }
+                            }
+                        },
+                        {
+                            "header": "description",
+                            "column": {
+                                "type": "text",
+                                "properties": {
+                                    "optional": False,
+                                    "datasets.v1.columnType": "Normal"
+                                }
+                            }
+                        }
+                    ],
+                    "properties": {}
+                },
+                name=str(uuid.uuid4()),
+                facets=[],
+                description="This is a test",
+                cause=[]
+            )
+
+            self.assertTrue(response["uuid"] is not None, "Dataset was created")
+
+        except Exception as e:
+
+            self.assertTrue(False, e)
+
+    def test_create_empty_dataset_from_flow(self):
+
+        flow_cols = [
+            {
+                "name": "name",
+                "dataType": "STRING",
+                "isOpt": True,
+                "columnType": "Normal"
+            },
+            {
+                "name": "description",
+                "dataType": "STRING",
+                "isOpt": True,
+                "columnType": "Normal"
+            }, {
+                "name": "engunits",
+                "dataType": "STRING",
+                "isOpt": True,
+                "columnType": "UnitOfMeasure"
+            }, {
+                "name": "EQUIPMENT_ID *",
+                "dataType": "STRING",
+                "isOpt": False,
+                "columnType": "EquipmentId"
+            }
+        ]
+
+        schema = {
+            "columns": FlowSchema(columns=flow_cols).to_dataset_schema(),
+            "properties": {}
+        }
+
+        try:
+            response = self.sources.create_command(
+                org_id=test_org,
+                schema=schema,
+                name=str(uuid.uuid4()),
+                facets=[],
+                description="This is a test",
+                cause=[]
+            )
+
+            self.assertTrue(response["uuid"] is not None, "Dataset from flow created")
+
+        except Exception as e:
+
+            self.assertTrue(False, e)
