@@ -34,6 +34,8 @@ from unify.assetaccess import AssetAccess
 from unify.graph import Graph
 from unify.hierarchies import Hierarchy
 from unify.helpers.SingleOrg import single_org
+from unify.permissions import Permissions
+from unify.helpers.Permissions import ArtifactType
 
 
 class ApiManager:
@@ -60,6 +62,8 @@ class ApiManager:
 
             self.hierarchies = Hierarchy(cluster=cluster, props=self.properties)
 
+            self.permissions = Permissions(cluster=cluster, props=self.properties)
+
             self.cluster = cluster
 
             self.sources.evergreen_enabled = self.evergreen_enabled
@@ -355,7 +359,7 @@ class ApiManager:
                             )
                         )
 
-                        self.sources.wait_for_dataset(org_id=org_id,dataset_id=new_source["data_set_id"])
+                        self.sources.wait_for_dataset(org_id=org_id, dataset_id=new_source["data_set_id"])
 
                         source_to_import["new_source_id"] = new_source["data_set_id"]
 
@@ -567,7 +571,8 @@ class ApiManager:
                         source_data["name"] = source_id_to_data[source_data["id"]]["name"]
 
                         if "ean_source_type" in source_id_to_data[source_data["id"]]["labels"]["raw"]:
-                            source_data["type"] = source_id_to_data[source_data["id"]]["labels"]["raw"]["ean_source_type"]
+                            source_data["type"] = source_id_to_data[source_data["id"]]["labels"]["raw"][
+                                "ean_source_type"]
                         else:
                             source_data["type"] = "api_dataset"
 
@@ -1207,3 +1212,100 @@ class ApiManager:
 
         except Exception as error:
             raise error
+
+    @single_org
+    def get_rules_list(self, org_id=None):
+        """
+
+        Retrieves the org rules
+        :param org_id: organization id to be queried
+        :return:
+        """
+
+        resp = self.permissions.get_rules(org_id=org_id)
+
+        return resp["data"]["permissions"]["getRules"]
+
+    @single_org
+    def get_selectors_list(self, org_id=None):
+        """
+
+        Retrieves selectors
+        :param org_id: organization id to be queried
+        :return:
+        """
+
+        resp = self.permissions.get_selector_definitions(org_id=org_id)
+
+        return resp["data"]["permissions"]["getSelectorDefinitions"]
+
+    @single_org
+    def get_permissions_org_config(self, org_id=None):
+        """
+
+        Retrieves org permissions config
+        :param org_id: organization id to be queried
+        :return:
+        """
+
+        resp = self.permissions.get_org_config(org_id=org_id)
+
+        return resp["data"]["permissions"]["getOrgConfig"]
+
+    @single_org
+    def get_pipeline_rules(self, org_id=None, *, pipeline_id):
+        resp = self.permissions.get_artifact_rules(
+            org_id=org_id, artifact_id=pipeline_id, artifact_type=ArtifactType.pipeline
+        )
+
+        return resp
+
+    @single_org
+    def get_dataset_rules(self, org_id=None, *, dataset_id):
+        resp = self.permissions.get_artifact_rules(
+            org_id=org_id, artifact_id=dataset_id, artifact_type=ArtifactType.dataset
+        )
+
+        return resp["data"]["permissions"]["getArtifactRules"]
+
+    @single_org
+    def check_permission(self, org_id=None, *, artifact_type, artifact_id, user_id, verb):
+        resp = self.permissions.check_permission(
+            org_id=org_id,
+            artifact_type=artifact_type,
+            artifact_id=artifact_id,
+            user_id=user_id,
+            verb=verb
+        )
+
+        return resp["data"]["permissions"]["check"]["allowed"]
+
+    @single_org
+    def get_selector_definition(self, org_id=None, *, selector_id):
+        resp = self.permissions.get_selector_definition(
+            org_id=org_id,
+            selector_id=selector_id
+        )
+        return resp["data"]["permissions"]['getSelectorDefinition']
+
+    @single_org
+    def add_rule(self, org_id=None, *, domain, verb, effect, userSelector, resourceSelector):
+        resp = self.permissions.add_rule(
+            org_id=org_id,
+            domain=domain,
+            verb=verb,
+            effect=effect,
+            userSelector=userSelector,
+            resourceSelector=resourceSelector
+        )
+        return resp["data"]["permissions"]
+
+    @single_org
+    def delete_rule(self, org_id=None, *, rule_id):
+
+        resp = self.permissions.delete_rule(
+            org_id=org_id,
+            rule_id=rule_id
+        )
+
+        return resp["data"]["permissions"]
