@@ -69,12 +69,6 @@ class ApiRequestManager:
                 cluster=self.cluster
             )
 
-        self.session.headers.update(
-            {
-                self.x_auth_token_header: self.props.get_auth_token(cluster=self.cluster)
-            }
-        )
-
         self.gql_url = self.props.get_remote(self.cluster) + "artifacts/graphql"
 
         self.upper_gql_builder = GraphQLBuilder()
@@ -120,7 +114,10 @@ class ApiRequestManager:
 
     def auth_token(self, query_params={}):
         """
-        Authenticates the given credentials and retrieves auth token
+        Authenticates the given credentials and retrieves auth token.
+
+        Note: this method doesn't pass an x-auth-token header - it's a
+        credential exchange to _get_ an auth-token.
 
         :return:
         """
@@ -155,7 +152,10 @@ class ApiRequestManager:
         :param query: GraphQL Query body
         :return:
         """
-        header = self.build_header(org_id=org_id)
+        header = self.build_header(
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
+        )
 
         query_results = self.session.post(
             self.gql_url,
@@ -251,7 +251,8 @@ class ApiRequestManager:
     def simple_get(self, final_url):
 
         header = self.build_header(
-            others=self.content_type_header
+            others=self.content_type_header,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         query_results = self.session.get(
