@@ -69,12 +69,6 @@ class Connectors(ApiRequestManager):
         """
         super().__init__(cluster=cluster, props=props, org_id=org_id)
 
-        self.session.headers.update(
-            {
-                self.x_auth_token_header: self.props.get_auth_token(cluster=self.cluster)
-            }
-        )
-
         remote = self.props.get_remote(self.cluster)
 
         self.connectors_url = remote + 'connectors/'
@@ -97,13 +91,20 @@ class Connectors(ApiRequestManager):
         :param config: connector config
         :return: connector id
         """
-        header = self.build_header(org_id=org_id)
+        header = self.build_header(
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
+        )
+
         body = {
             'name': name,
             'type': connector_type,
             'config': config,
         }
+
         result = self.session.post(self.connectors_url, headers=header, json=body)
+
         if result.status_code in self.OK:
             return json.loads(result.content)
 
@@ -123,6 +124,7 @@ class Connectors(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -153,6 +155,7 @@ class Connectors(ApiRequestManager):
         """
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
         result =  self.session.put(
             self.update_config_url.format(connector_id),
@@ -177,6 +180,7 @@ class Connectors(ApiRequestManager):
         """
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
         result = self.session.get(self.get_connector_url.format(connector_id), headers=header)
 
@@ -195,6 +199,7 @@ class Connectors(ApiRequestManager):
         """
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
         result = self.session.delete(self.get_connector_url.format(connector_id), headers=header)
 
@@ -249,6 +254,7 @@ class Connectors(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         result = self.session.post(
@@ -273,6 +279,7 @@ class Connectors(ApiRequestManager):
         """
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
         result = self.session.get(self.get_artifacts_url.format(connector_id), headers=header)
 
@@ -293,6 +300,7 @@ class Connectors(ApiRequestManager):
         """
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
         result = self.session.post(
             self.get_artifacts_url.format(connector_id),
@@ -350,7 +358,11 @@ class Connectors(ApiRequestManager):
         :param config: connector config
         :return: connector id and user info
         """
-        header = self.build_header(org_id=org_id)
+        header = self.build_header(
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
+        )
+
         body = {
             'name': name,
             'type': connector_type,
