@@ -39,12 +39,6 @@ class Hierarchy(ApiRequestManager):
         """
         super().__init__(cluster=cluster, props=props, org_id=org_id)
 
-        self.session.headers.update(
-            {
-                self.x_auth_token_header: self.props.get_auth_token(cluster=self.cluster)
-            }
-        )
-
         remote = self.props.get_remote(self.cluster)
 
         self.home_hierarchies_url = remote + "api/v2/orgs/{}/asset_hierarchies"
@@ -65,6 +59,7 @@ class Hierarchy(ApiRequestManager):
         """
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -96,6 +91,7 @@ class Hierarchy(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -136,6 +132,7 @@ class Hierarchy(ApiRequestManager):
         """
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -162,6 +159,7 @@ class Hierarchy(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
