@@ -129,6 +129,7 @@ class Pipelines(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.delete_content_type_header
         )
 
@@ -155,6 +156,7 @@ class Pipelines(ApiRequestManager):
 
         headers = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others={"Content-Type": "application/json"}
         )
 
@@ -196,7 +198,9 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            org_id=org_id, others=self.content_type_header
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         update_payload["name"] = str(pipeline_name)
@@ -264,6 +268,7 @@ class Pipelines(ApiRequestManager):
         """
         headers = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -324,6 +329,7 @@ class Pipelines(ApiRequestManager):
 
         headers = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others={"'Content-Type'": "application/data"}
         )
 
@@ -363,6 +369,7 @@ class Pipelines(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -398,6 +405,7 @@ class Pipelines(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -425,6 +433,7 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -447,8 +456,9 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            others=self.content_type_header,
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         result = self.session.delete(
@@ -470,8 +480,9 @@ class Pipelines(ApiRequestManager):
         :return:
         """
         header = self.build_header(
-            others=self.content_type_header,
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         update_payload = {"status": "draft"}
@@ -503,6 +514,7 @@ class Pipelines(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -542,6 +554,7 @@ class Pipelines(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -679,8 +692,9 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            others=self.content_type_header,
-            org_id=str(org_id)
+            org_id=str(org_id),
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         cookies = {'_gid': 'GA1.1.1649742346.1580648966'}
@@ -711,8 +725,9 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            others=self.content_type_header,
-            org_id=str(org_id)
+            org_id=str(org_id),
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         schema_url = self.preview_data_pipeline.format(org_id, pipeline_id, flow_id, sort_column)
@@ -736,8 +751,9 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            others=self.content_type_header,
-            org_id=str(org_id)
+            org_id=str(org_id),
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         schema_url = self.count_endpoint.format(org_id, pipeline_id, flow_id)
@@ -760,8 +776,9 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            others=self.content_type_header,
-            org_id=str(org_id)
+            org_id=str(org_id),
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         run_url = self.run_pipeline_url.format(org_id, pipeline_id)
@@ -788,8 +805,9 @@ class Pipelines(ApiRequestManager):
         :return:
         """
         headers = self.build_header(
-            others=self.content_type_header,
-            org_id=str(org_id)
+            org_id=str(org_id),
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         if count:
@@ -817,8 +835,9 @@ class Pipelines(ApiRequestManager):
         :return:
         """
         headers = self.build_header(
-            others=self.content_type_header,
-            org_id=str(org_id)
+            org_id=str(org_id),
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         payload = {"autoSyncEnabled": autoSyncEnabled}
@@ -848,8 +867,9 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            others=self.content_type_header,
-            org_id=str(org_id)
+            org_id=str(org_id),
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         status_url = self.run_pipeline_status_url.format(org_id, pipeline_id)
@@ -889,8 +909,9 @@ class Pipelines(ApiRequestManager):
             raise Exception("Component list must have at least one ID")
 
         headers = self.build_header(
-            others=self.content_type_header,
-            org_id=str(org_id)
+            org_id=str(org_id),
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
         )
 
         payload = {"componentIds": components}
