@@ -562,6 +562,7 @@ class Sources(ApiRequestManager):
         """
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others={"'Content-Type'": "application/data"}
         )
 
@@ -583,7 +584,8 @@ class Sources(ApiRequestManager):
         :return:
         """
         header = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         get_source_request = self.session.get(
@@ -645,6 +647,49 @@ class Sources(ApiRequestManager):
 
         return json.dumps(all_datasets)
 
+    @single_org
+    def add_data_content_to_existing_source(
+            self, name, org_id=None, *, content,
+            data_set_id, group_id=None, format="csv"):
+        """
+        Helper function to append data to existing dataset
+
+        :param name: Name of the current file, used for staging the file
+        :type name: str
+        :param org_id: Org id where the target dataset exists
+        :type org_id: int or str
+        :param content: content of append data
+        :param data_set_id: Dataset id where the content will be appended
+        :type data_set_id: int or str
+        :param group_id: Group identification that the dataset belongs
+        :type group_id: str
+        :param format: File format. Accepts "CSV" or "TSV"
+        :type format: str, optional
+        :return:
+        """
+        results = {}
+
+        stage = self.stage_file_with_content(
+            name=name,
+            org_id=org_id,
+            file_data=content,
+            group_id=group_id,
+            format=format,
+        )
+
+        results["group_id"] = stage
+
+        final_commit = self.append_command(
+            org_id=org_id,
+            data_set_id=data_set_id,
+            name=name,
+            group_id=results["group_id"]
+        )
+
+        results.update(final_commit)
+
+        return results
+
     @single_org
     def add_data_to_existing_source(
             self, name, org_id=None, *, file_path,
@@ -745,6 +790,7 @@ class Sources(ApiRequestManager):
     def _commit_dataset_command(self, org_id, data_set_id, command):
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others={"'Content-Type'": "application/data"}
         )
 
@@ -804,7 +850,8 @@ class Sources(ApiRequestManager):
         os.close(file_dir)
 
         headers = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         files = {'file': open(path, "rb")}
@@ -852,7 +899,6 @@ class Sources(ApiRequestManager):
         :param data_set_id: Dataset id to be appended
         :type data_set_id: str
         :param group_id: Group identification that the dataset belongs
-        :type group_id: str
         :param name: Name of the staged file
         :type name: str
         :return:
@@ -860,12 +906,7 @@ class Sources(ApiRequestManager):
         command = {
             "commands":
                 [
-                    {
-                        "$type": "append",
-                        "name": name,
-                        "group": group_id.decode(),
-                        "cause": []
-                    }
+                    self.single_append_command(group_id=group_id, name=name)
                 ]
         }
         return self._commit_dataset_command(org_id, data_set_id, command)
@@ -912,25 +953,25 @@ class Sources(ApiRequestManager):
         :return:
         """
         header = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others={"'Content-Type'": "application/octet-stream"}
         )
 
-        header.update({"'Content-Type'": "application/octet-stream"})
-
-        headers = dict(header.items())
-
         if group_id is None:
             payload_data = {
                 "name": name,
                 "convertToParquet": convert_to_parquet,
-                "format": format
+                "format": format,
+                "charset": encoding
             }
         else:
             payload_data = {
                 "name": name,
                 "convertToParquet": convert_to_parquet,
                 "format": format,
-                "groupId": group_id
+                "groupId": group_id,
+                "charset": encoding
             }
 
         if encode:
@@ -940,7 +981,7 @@ class Sources(ApiRequestManager):
 
         test_request = self.session.post(
             self.stage_file_url,
-            headers=headers,
+            headers=header,
             data=file_data,
             params=payload_data
         )
@@ -1010,13 +1051,11 @@ class Sources(ApiRequestManager):
         :return:
         """
         header = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others={"'Content-Type'": "application/octet-stream"}
         )
 
-        header.update({"'Content-Type'": "application/octet-stream"})
-
-        headers = dict(header.items())
-
         if group_id is None:
 
             payload_data = {
@@ -1036,7 +1075,7 @@ class Sources(ApiRequestManager):
 
         test_request = self.session.post(
             self.stage_file_url,
-            headers=headers,
+            headers=header,
             data=file_data.encode(encoding),
             params=payload_data
         )
@@ -1058,14 +1097,13 @@ class Sources(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others={"'Content-Type'": "application/data"}
         )
 
-        headers = dict(header.items())
-
         schema_request = self.session.post(
             self.post_data_set_schema_url,
-            headers=headers,
+            headers=header,
             data=schema_data.encode(encoding)
         )
 
@@ -1102,7 +1140,8 @@ class Sources(ApiRequestManager):
         """
 
         headers = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         upload_file = {'file': open(file_path, "rb")}
@@ -1143,7 +1182,8 @@ class Sources(ApiRequestManager):
             query_strings["charset"] = encoding
 
         headers = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         files = {'file': open(content, "rb")}
@@ -1268,8 +1308,8 @@ class Sources(ApiRequestManager):
         """
 
         headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -1301,8 +1341,8 @@ class Sources(ApiRequestManager):
         """
 
         headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -1334,8 +1374,8 @@ class Sources(ApiRequestManager):
         """
 
         headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -1427,7 +1467,10 @@ class Sources(ApiRequestManager):
         :param sequenceNr: Optional, the number of the first event to be returned
         :return: A list with the events
         """
-        header = self.build_header(org_id=org_id)
+        header = self.build_header(
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
+        )
         params = {'fromSequenceNr': sequenceNr}
         response = self.session.get(
             self.datastream_events_info_url.format(dataset_id),
@@ -1455,7 +1498,10 @@ class Sources(ApiRequestManager):
         :param sequenceNr: the number of the datastream event to be returned
         :return: A csv string with the data starting from event specified
         """
-        header = self.build_header(org_id=org_id)
+        header = self.build_header(
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
+        )
         params = {'fromSequenceNr': sequenceNr}
         response = self.session.get(
             self.datastream_download_events.format(dataset_id),
@@ -1479,7 +1525,8 @@ class Sources(ApiRequestManager):
                        facets: list,
                        description: str,
                        cause: list,
-                       dataset_uuid=None):
+                       dataset_uuid=None,
+                       is_stream: bool = False):
         """
 
         :param org_id: organization id
@@ -1496,19 +1543,22 @@ class Sources(ApiRequestManager):
         :type cause: list
         :param dataset_uuid: Override of the dataset id
         :type dataset_uuid: str
+        :param is_stream: decides if the created dataset is a stream dataset
+        :type is_stream: bool
         :return: server response from the server
         """
 
         body = {
-            "commands": [{
-                "$type": "create",
-                "schema": schema,
-                "org": str(org_id),
-                "name": name,
-                "facets": facets,
-                "description": description,
-                "cause": cause
-            }]
+            "commands": [
+                self.single_create_command(
+                    schema=schema,
+                    org_id=org_id,
+                    name=name,
+                    is_stream=is_stream,
+                    facets=facets,
+                    description=description,
+                    cause=cause)
+            ]
         }
 
         data_set_id = dataset_uuid if dataset_uuid is not None else str(uuid.uuid4())
@@ -1523,3 +1573,19 @@ class Sources(ApiRequestManager):
 
         except Exception as es:
             raise Exception(es)
+
+    def single_append_command(self, group_id, name):
+
+        return {"$type": "append", "name": name, "group": group_id.decode(), "cause": []}
+
+    def single_create_command(self, schema, org_id, name, is_stream, facets, description, cause):
+        return {
+            "$type": "create",
+            "schema": schema,
+            "org": org_id,
+            "name": name,
+            "isBounded": not is_stream,
+            "facets": facets,
+            "description": description,
+            "cause": cause
+        }
